@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2014, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -19,6 +19,9 @@
 //#define NDEBUG
 //#define VIENNACL_BUILD_INFO
 
+// We don't need debug mode in UBLAS:
+#define BOOST_UBLAS_NDEBUG
+
 #include <utility>
 #include <iostream>
 #include <fstream>
@@ -64,7 +67,7 @@ bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A,
     {
       if (ublas_A(i,j) != vcl_A_cpu(i,j))
       {
-        if ( (std::abs(ublas_A(i,j) - vcl_A_cpu(i,j)) / std::max(ublas_A(i,j), vcl_A_cpu(i,j)) > epsilon) || (vcl_A_cpu(i,j) != vcl_A_cpu(i,j)) )
+        if ( (std::abs(ublas_A(i,j) - vcl_A_cpu(i,j)) / std::max(std::fabs(ublas_A(i,j)), std::fabs(vcl_A_cpu(i,j))) > epsilon) || (vcl_A_cpu(i,j) != vcl_A_cpu(i,j)) )
         {
           std::cout << "Error at index (" << i << ", " << j << "): " << ublas_A(i,j) << " vs " << vcl_A_cpu(i,j) << std::endl;
           std::cout << std::endl << "TEST failed!" << std::endl;
